# Scratch Notebooks

These notebooks are NOT part of the library and will not be run when executing the command `nbdev_build_lib`. This is helpful for things like testing imports and functionality in longer running notebooks without slowing down build times.

